pub enum MaterialIconColor {
Dark,
DarkInactive,
Light,
LightInactive,
Custom(String),
}Expand description
Colors of Material Icons
As described here.
Variants
Dark
For using icons as black on a light background.
DarkInactive
For using icons as black on a light background.
Light
For using icons as white on a dark background.
LightInactive
For using icons as white on a dark background.
Custom(String)
Custom color, any valid CSS color
E.g.: #0000ff or red
Implementations
Sourceimpl MaterialIconColor
impl MaterialIconColor
Sourcepub fn to_css_color(&self) -> &str
pub fn to_css_color(&self) -> &str
Converts the color to its corresponding CSS color